---
title: "A Typescript for the Web"
subtitle: "Why HTML is a better starting point than .docx"
author: Wendell Piez and Adam Hyde
date: "2016-12-05"
category: "article"
---

<p>Originally written in 2016, small updates in 2022.</a>
<p>In the days of the typewriter, a&nbsp;typescript was a typed copy of a work. The typescript copy was used for improving the document through the editorial process&nbsp;–&nbsp;for reviewing, commenting, fact and rights checking, revision etc.</p>
<p>For many years, since the advent of desktop publishing, the hand-typed typescript has been replaced by Microsoft Word documents. This advanced the publishing world quite a bit. Emailing typescript in the form of Word documents was far easier than mailing paper copies, and making revised copies moved from being an arduous typing exercise to the one click ‘save as’<span style="color: #ff0000;">.</span> There are obvious efficiencies.<p></p>
<p>But now we are in the age of networked documents. We have the opportunity to make another paradigmatic workflow change – in a sense: bringing typescript&nbsp;to the browser. With this evolution, we can bring an end to many of the frustrations of emailing Word documents around for comment and revision – while exploring wider options&nbsp;for collaboration, innovating more interesting content types, more easily understanding and managing a document’s history, using automated typesetting and data exchange. All of these represent cost and time savings for&nbsp;the publishing process and have the potential to move the communication of research beyond the <a href="https://coko.foundation/publishing-for-reproducibility-collaborative-input-and-networked-output/">limited paradigm of the manuscript.</a></p>
<p>However, migrating typescript&nbsp;formats away from the desktop to the web has proven to be very difficult.&nbsp;One of the major problems&nbsp;is that while there is a growing&nbsp;move towards online authoring environments, many authors still start in Word, and many previous attempts&nbsp;have shown that MS Word is not an easy file format to convert to other formats. Fortunately, we believe, <em>if we think of MS Word&nbsp;as a software for “typescript preparation,”</em>&nbsp;that HTML is&nbsp;a viable option for conversion from Word’s &nbsp;.docx format into a typescript format ready for the web.</p>
<p>HTML works out well as a format for these purposes due to&nbsp;features that are more commonly considered weaknesses. How so? Well,&nbsp;first we must consider that, at early stages&nbsp;of a publishing workflow, a Word document&nbsp;will&nbsp;not have achieved its final structure, or indeed, much of any structure at all. Nonetheless, attempts to ‘get out of Word’ have tried to jump from unstructured Word to very structured XML formats by:</p>
<a href="#"></a>
<ol>
<li>copying over all the data in the document and</li>
<li>interpolating structure at the same time in an attempt to ‘understand’ the “intent of the author” (or a proxy) as represented by the display semantics of the document.</li>
</ol>
<p>But if the structure does not exist in the first place, you have a problem. It is a little like going, as Peter Murray Rust has previously commented, <a href="https://blogs.ch.cam.ac.uk/pmr/2006/09/10/hamburgers-and-cows-the-cognitive-style-of-pdf/">from Hamburger to Cow</a>.</p>
<p>However, with the <a href="https://gitlab.coko.foundation/wendell/XSweet">XSweet</a> Word-to-HTML scripts we are developing,&nbsp;we retain&nbsp;step one (copying over all the data) and replace step two (interpolating structure) with a process that forsakes the introduction of any structure in favor of carrying over whatever information from the original Word file might be useful later on, whether for programmatically understanding or <em>manually applying</em> document structure. The best solution&nbsp;of course, being a little bit of both.</p>
<p>Hence we:</p>
<ol>
<li>convert the unstructured Word document into an unstructured (or partially better structured) HTML document; and</li>
<li>interpret the original Word file and&nbsp;carry forward as much information as that original Word file contained for possible future use in interpreting the document structure – or representing any features of interest – <em>while not actually structuring the document</em>.</li>
</ol>
<p>Interestingly, since HTML does not require you to&nbsp;enforce a strict document structure if you do not have it, an unstructured document flows into HTML as easily as a structured, or partially structured, document flows&nbsp;into it. If your aim is a well-controlled document format, such a failure to enforce strict&nbsp;structures is regarded as a flaw or weakness. Yet, since we do not have much or any document structure in the originating Word document, and our goal is to improve it – HTML’s flexibility becomes a critical feature.</p>
<p>This process produces&nbsp;an intermediary carrier format — an information- rich, sanitized&nbsp;HTML format that is suitable for improvement. In&nbsp;an HTML editor, we can then bring to bear further tools for adding structure, reviewing, commenting, revising.&nbsp;Hence, there is a kind of similarity to its historical predecessor – which is why we are using the working title ‘HTML typescript’.</p>
<p>If the decision is to improve the structure programmatically, the Coko XSweet platform comes in nicely. A developer can use an XSweet “docx extraction” to get to HTML typescript, and then write (or reuse) another step, in the language of their choice, to do structural&nbsp;interpolation. By separating concerns here, XSweet allows developers to provide structural interpolations that suit the kinds of content their organisations are working with, in the way that makes most sense for them.</p>
<p>When manual improvement is required, we can&nbsp;use sophisticated editors like those built with the <a href="http://prosemirror.net">ProseMirror</a> libraries (such as <a href="https://waxjs.net">Wax</a>). These editor manages strict control of&nbsp;the source and ensure&nbsp;that the manually applied structure&nbsp;is semantically robust. This also means that we can apply explicit structure to the text and co-relate that to the other output formats we require, such as JATS XML as Coko has done with the Wax-JATS editor.</p>
<p>It is not a revolutionary new approach, rather a shift in emphasis. By&nbsp;avoiding over-complicating the conversion as described above, we have been able to&nbsp;make faster headway –&nbsp;and to turn our focus to the tools required to support the editorial processes via a web-based typescript.</p>
<p><em>Post by Wendell Piez and Adam Hyde.</em></p>
